# CHANGELOG

<!-- version list -->

## v1.0.1 (2026-03-03)

### Bug Fixes

- **docs**: Correct docstring indentation for griffe strict mode
  ([`d8fb143`](https://github.com/michaelellis003/smcjax/commit/d8fb1439c7f1fc19527436becb049051ed4401ac))

### Refactoring

- Reduce duplication across particle filters and diagnostics
  ([#10](https://github.com/michaelellis003/smcjax/pull/10),
  [`08e91b3`](https://github.com/michaelellis003/smcjax/commit/08e91b36814c5c45bdf2b8d2dc1efa50410a6fb3))


## v1.0.0 (2026-03-02)

- Initial Release
